/*
* Copyright (c) 2024 Manuel Einfalt
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the “Software”), to
* deal in the Software without restriction, including without limitation the
* rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
* sell copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
* IN THE SOFTWARE. 
*/

#ifndef __WGIF_H__
#define __WGIF_H__
#include <stdint.h>

struct gif_file {
    int globColSz;
    void *wparm;
    int (*wr_fnct)(uint8_t *p, size_t len, void *wparm);
};

int gif_plainText(struct gif_file *gf, uint16_t left, uint16_t top, uint16_t width, uint16_t height, uint8_t cellWidth, uint8_t cellHeight, uint8_t fg, uint8_t bg, char *txt);
int gif_comment(struct gif_file *gf, char *str);
int gif_end(struct gif_file *gf);
int gif_ext_loop(struct gif_file *gf, uint16_t loops);
int gif_graphicControlExtension(struct gif_file *gf, uint16_t delay_time, int transparent_color);
int gif_init(struct gif_file *gf, uint16_t width, uint16_t height, uint32_t *colortab, int colortab_sz, uint8_t bgcol_idx);
int gif_image(struct gif_file *gf, uint16_t imgLeftPos, uint16_t imgTopPos, uint16_t width, uint16_t height, uint32_t *colorTab, int colorTabSz, uint8_t *pixmap);

#endif
